from django.contrib.sitemaps import Sitemap
from django.urls import reverse


class StaticViewSitemap(Sitemap):
    priority = 0.5
    changefreq = 'weekly'

    def items(self):
        return [
            'bocords:home',
        ]

    def location(self, item):
        return reverse(item)



from django.template import Library
from shared_lib.models import PortfolioCategory, Portfolio


register = Library()

# https://localcoder.org/django-inclusion-tag-with-configurable-template

@register.inclusion_tag("bocor/components/portfolio.html")
def portfolio(title, subtitle):
    categories = PortfolioCategory.objects.all()
    items = Portfolio.objects.all()
    context = {
        'categories': categories,
        'items': items,
        'title': title,
        'subtitle': subtitle,
    }
    return context




from shared_lib import utils
from _data import bocor, shared_lib

c = bocor.context
c.update(shared_lib.analytics)


def bocor_home(request):
    return utils.home(request,'bocor/index.html', c)

def bocor_terms(request):
    return utils.terms(request, 'bocor/pages/terms.html', c)

def bocor_privacy(request):
    return utils.privacy(request, 'bocor/pages/privacy.html', c)

def bocor_portfolio_details(request, pk):
    return utils.portfolio_details(request, 'bocor/pages/portfolio_details.html', pk, c)



from django.urls import path
from django.contrib.sitemaps.views import sitemap
from . import views

from shared_lib.sitemaps import PortfolioSitemap
from .sitemaps import StaticViewSitemap

app_name = 'bocor'

sitemaps = {
    "portfolios": PortfolioSitemap,
    'static': StaticViewSitemap,
}

urlpatterns = [
    path('', views.bocor_home, name='home'),
    path("sitemap.xml", sitemap, {"sitemaps": sitemaps}, name="django.contrib.sitemaps.views.sitemap", ),

    path('portfolio_details/<int:pk>/', views.bocor_portfolio_details, name='portfolio_details'),

    path('terms_of_use/', views.bocor_terms, name='terms'),
    path('privacy_policy/', views.bocor_privacy, name='privacy'),
]
